var _context, _context2, _context3, _context4, _context5, _context6, _context7, _context8, _context9, _context0, _context1, _context10, _context11, _context12;
import _toSortedInstanceProperty from "core-js-pure/stable/instance/to-sorted.js";
import _Array$from from "core-js-pure/stable/array/from.js";
_toSortedInstanceProperty(a).call(a, x);
_toSortedInstanceProperty(a)?.call(a, x);
_toSortedInstanceProperty(_context = a.b)?.call(_context, x);
_toSortedInstanceProperty(_context2 = a.b)?.call(_context2, x).c;
_toSortedInstanceProperty(_context3 = a.b)?.call(_context3, x)?.c;
((_context4 = a) == null ? void 0 : Function.call.bind(_toSortedInstanceProperty(_context4), _context4))?.(x);
((_context5 = a) == null ? void 0 : Function.call.bind(_toSortedInstanceProperty(_context6 = _context5.b), _context6))?.(x).c;
((_context7 = a.b) == null ? void 0 : Function.call.bind(_toSortedInstanceProperty(_context7), _context7))?.(x).c;
((_context8 = a) == null ? void 0 : Function.call.bind(_toSortedInstanceProperty(_context9 = _context8.b), _context9))?.(x)?.c;
((_context0 = a.b) == null ? void 0 : Function.call.bind(_toSortedInstanceProperty(_context0), _context0))?.(x)?.c;
((_context1 = a) == null ? void 0 : _toSortedInstanceProperty(_context10 = _context1.b))?.call(_context10, x).c;
_toSortedInstanceProperty(a.b.c)?.d.e;
((_context11 = a.b) == null ? void 0 : _toSortedInstanceProperty(_context11.c))?.d.e;
((_context12 = a.b) == null ? void 0 : _toSortedInstanceProperty(_context12.c))?.d.e;
_Array$from(x);
_Array$from(x);
_Array$from(x).c;
_Array$from(x)?.c;
_Array$from(x);
_Array$from(x).c;
_Array$from(x)?.c;
_Array$from(x);
_Array$from(x).c;
_Array$from(x)?.c;
_Array$from;
_Array$from.x.y;
_Array$from.x.y;
_Array$from.x.y;
_Array$from.x?.y;
_Array$from.x().y?.();
