import "core-js/modules/es.array.iterator.js";
import "core-js/modules/es.string.pad-end.js";
import "core-js/modules/es.string.pad-start.js";
for (const {
  padStart
} of foo) {
  console.log('b'.padEnd(5));
}
