var _concatInstanceProperty = require("core-js-pure/stable/instance/concat.js");
var _context;
"".concat(b);
_concatInstanceProperty(_context = []).call(_context, b);
_concatInstanceProperty(a).call(a, b);
