var _bindInstanceProperty = require("core-js-pure/stable/instance/bind.js");
var _codePointAtInstanceProperty = require("core-js-pure/stable/instance/code-point-at.js");
var _concatInstanceProperty = require("core-js-pure/stable/instance/concat.js");
var _copyWithinInstanceProperty = require("core-js-pure/stable/instance/copy-within.js");
var _endsWithInstanceProperty = require("core-js-pure/stable/instance/ends-with.js");
var _entriesInstanceProperty = require("core-js-pure/stable/instance/entries.js");
var _everyInstanceProperty = require("core-js-pure/stable/instance/every.js");
var _fillInstanceProperty = require("core-js-pure/stable/instance/fill.js");
var _filterInstanceProperty = require("core-js-pure/stable/instance/filter.js");
var _findInstanceProperty = require("core-js-pure/stable/instance/find.js");
var _findIndexInstanceProperty = require("core-js-pure/stable/instance/find-index.js");
var _flagsInstanceProperty = require("core-js-pure/stable/instance/flags.js");
var _flatMapInstanceProperty = require("core-js-pure/stable/instance/flat-map.js");
var _flatInstanceProperty = require("core-js-pure/stable/instance/flat.js");
var _forEachInstanceProperty = require("core-js-pure/stable/instance/for-each.js");
var _includesInstanceProperty = require("core-js-pure/stable/instance/includes.js");
var _indexOfInstanceProperty = require("core-js-pure/stable/instance/index-of.js");
var _keysInstanceProperty = require("core-js-pure/stable/instance/keys.js");
var _lastIndexOfInstanceProperty = require("core-js-pure/stable/instance/last-index-of.js");
var _mapInstanceProperty = require("core-js-pure/stable/instance/map.js");
var _matchAllInstanceProperty = require("core-js-pure/features/instance/match-all.js");
var _padEndInstanceProperty = require("core-js-pure/stable/instance/pad-end.js");
var _padStartInstanceProperty = require("core-js-pure/stable/instance/pad-start.js");
var _reduceInstanceProperty = require("core-js-pure/stable/instance/reduce.js");
var _reduceRightInstanceProperty = require("core-js-pure/stable/instance/reduce-right.js");
var _repeatInstanceProperty = require("core-js-pure/stable/instance/repeat.js");
var _replaceAllInstanceProperty = require("core-js-pure/features/instance/replace-all.js");
var _reverseInstanceProperty = require("core-js-pure/stable/instance/reverse.js");
var _sliceInstanceProperty = require("core-js-pure/stable/instance/slice.js");
var _someInstanceProperty = require("core-js-pure/stable/instance/some.js");
var _sortInstanceProperty = require("core-js-pure/stable/instance/sort.js");
var _spliceInstanceProperty = require("core-js-pure/stable/instance/splice.js");
var _startsWithInstanceProperty = require("core-js-pure/stable/instance/starts-with.js");
var _trimInstanceProperty = require("core-js-pure/stable/instance/trim.js");
var _trimEndInstanceProperty = require("core-js-pure/stable/instance/trim-end.js");
var _trimLeftInstanceProperty = require("core-js-pure/stable/instance/trim-left.js");
var _trimRightInstanceProperty = require("core-js-pure/stable/instance/trim-right.js");
var _trimStartInstanceProperty = require("core-js-pure/stable/instance/trim-start.js");
var _valuesInstanceProperty = require("core-js-pure/stable/instance/values.js");
object.at;
_bindInstanceProperty(object);
_codePointAtInstanceProperty(object);
object.codePoints;
_concatInstanceProperty(object);
_copyWithinInstanceProperty(object);
_endsWithInstanceProperty(object);
_entriesInstanceProperty(object);
_everyInstanceProperty(object);
_fillInstanceProperty(object);
_filterInstanceProperty(object);
_findInstanceProperty(object);
_findIndexInstanceProperty(object);
_flagsInstanceProperty(object);
_flatMapInstanceProperty(object);
_flatInstanceProperty(object);
_forEachInstanceProperty(object);
_includesInstanceProperty(object);
_indexOfInstanceProperty(object);
_keysInstanceProperty(object);
_lastIndexOfInstanceProperty(object);
_mapInstanceProperty(object);
_matchAllInstanceProperty(object);
_padEndInstanceProperty(object);
_padStartInstanceProperty(object);
_reduceInstanceProperty(object);
_reduceRightInstanceProperty(object);
_repeatInstanceProperty(object);
_replaceAllInstanceProperty(object);
_reverseInstanceProperty(object);
_sliceInstanceProperty(object);
_someInstanceProperty(object);
_sortInstanceProperty(object);
_spliceInstanceProperty(object);
_startsWithInstanceProperty(object);
_trimInstanceProperty(object);
_trimEndInstanceProperty(object);
_trimLeftInstanceProperty(object);
_trimRightInstanceProperty(object);
_trimStartInstanceProperty(object);
_valuesInstanceProperty(object);
object.something;
object.at(arg);
_bindInstanceProperty(object).call(object, arg);
_codePointAtInstanceProperty(object).call(object, arg);
object.codePoints(arg);
_concatInstanceProperty(object).call(object, arg);
_copyWithinInstanceProperty(object).call(object, arg);
_endsWithInstanceProperty(object).call(object, arg);
_entriesInstanceProperty(object).call(object, arg);
_everyInstanceProperty(object).call(object, arg);
_fillInstanceProperty(object).call(object, arg);
_filterInstanceProperty(object).call(object, arg);
_findInstanceProperty(object).call(object, arg);
_findIndexInstanceProperty(object).call(object, arg);
_flagsInstanceProperty(object).call(object, arg);
_flatMapInstanceProperty(object).call(object, arg);
_flatInstanceProperty(object).call(object, arg);
_forEachInstanceProperty(object).call(object, arg);
_includesInstanceProperty(object).call(object, arg);
_indexOfInstanceProperty(object).call(object, arg);
_keysInstanceProperty(object).call(object, arg);
_lastIndexOfInstanceProperty(object).call(object, arg);
_mapInstanceProperty(object).call(object, arg);
_matchAllInstanceProperty(object).call(object, arg);
_padEndInstanceProperty(object).call(object, arg);
_padStartInstanceProperty(object).call(object, arg);
_reduceInstanceProperty(object).call(object, arg);
_reduceRightInstanceProperty(object).call(object, arg);
_repeatInstanceProperty(object).call(object, arg);
_replaceAllInstanceProperty(object).call(object, arg);
_reverseInstanceProperty(object).call(object, arg);
_sliceInstanceProperty(object).call(object, arg);
_someInstanceProperty(object).call(object, arg);
_sortInstanceProperty(object).call(object, arg);
_spliceInstanceProperty(object).call(object, arg);
_startsWithInstanceProperty(object).call(object, arg);
_trimInstanceProperty(object).call(object, arg);
_trimEndInstanceProperty(object).call(object, arg);
_trimLeftInstanceProperty(object).call(object, arg);
_trimRightInstanceProperty(object).call(object, arg);
_trimStartInstanceProperty(object).call(object, arg);
_valuesInstanceProperty(object).call(object, arg);
_bindInstanceProperty(Function);
object.something(arg);
