import _createClass from "@babel/runtime-corejs3/helpers/createClass";
import _classCallCheck from "@babel/runtime-corejs3/helpers/classCallCheck";
import _inherits from "@babel/runtime-corejs3/helpers/inherits";
import _callSuper from "@babel/runtime-corejs3/helpers/callSuper";
import _defineProperty from "@babel/runtime-corejs3/helpers/defineProperty";
import _concatInstanceProperty from "core-js-pure/stable/instance/concat.js";
let A = /*#__PURE__*/function (_B) {
  function A(...args) {
    var _context;
    var _this;
    _classCallCheck(this, A);
    _this = _callSuper(this, A, _concatInstanceProperty(_context = []).call(_context, args));
    _defineProperty(_this, "b", 1);
    return _this;
  }
  _inherits(A, _B);
  return _createClass(A);
}(B);
