var _AggregateError = require("core-js-pure/features/aggregate-error.js");
var _Map = require("core-js-pure/features/map/index.js");
var _Observable = require("core-js-pure/features/observable/index.js");
var _Promise = require("core-js-pure/features/promise/index.js");
var _Set = require("core-js-pure/features/set/index.js");
var _Symbol = require("core-js-pure/features/symbol/index.js");
var _URL = require("core-js-pure/features/url/index.js");
var _URLSearchParams = require("core-js-pure/features/url-search-params/index.js");
var _WeakMap = require("core-js-pure/features/weak-map/index.js");
var _WeakSet = require("core-js-pure/features/weak-set/index.js");
var _clearImmediate = require("core-js-pure/features/clear-immediate.js");
var _compositeKey = require("core-js-pure/features/composite-key.js");
var _compositeSymbol = require("core-js-pure/features/composite-symbol.js");
var _globalThis = require("core-js-pure/features/global-this.js");
var _parseFloat = require("core-js-pure/features/parse-float.js");
var _parseInt = require("core-js-pure/features/parse-int.js");
var _queueMicrotask = require("core-js-pure/features/queue-microtask.js");
var _setImmediate = require("core-js-pure/features/set-immediate.js");
var _setInterval = require("core-js-pure/features/set-interval.js");
var _setTimeout = require("core-js-pure/features/set-timeout.js");
_AggregateError;
_Map;
_Observable;
_Promise;
_Set;
_Symbol;
_URL;
_URLSearchParams;
_WeakMap;
_WeakSet;
_clearImmediate;
_compositeKey;
_compositeSymbol;
_globalThis;
_parseFloat;
_parseInt;
_queueMicrotask;
_setImmediate;
_setInterval;
_setTimeout;
Array;
Boolean;
Date;
Infinity;
JSON;
NaN;
Number;
Object;
clearInterval;
clearTimeout;
something;
