var _Promise = require("core-js-pure/stable/promise/index.js");
var _Symbol = require("core-js-pure/stable/symbol/index.js");
var _Map = require("core-js-pure/stable/map/index.js");
obj.constructor === Object;
obj.constructor === _Promise;
_Symbol();
_Symbol("test");
new _Map();
