import _Promise from "@babel/runtime-corejs3/core-js-stable/promise.js";
import _forEachInstanceProperty from "@babel/runtime-corejs3/core-js-stable/instance/for-each.js";
_Promise.allSettled(1, 2, 3);
Observable(1, 2, 3);
_forEachInstanceProperty(foo).call(foo, cb);
